+++
title = "Reflectometry"
weight = 10
+++

## Specular reflectometry simulation

As introductory example, we simulate specular reflectometry
by a sample that consists of 10 Ti/Ni double layers on a Si substrate.

The same script has been used in preceding pages
to explain [usage]({{% ref-py "start/run.md" %}})
and [syntax]({{% ref-py "start/syntax.md" %}})
of BornAgain Python code.

### Example script

To generate this image

{{< figscg src="/img/auto/specular/AlternatingLayers1.png" width="500" class="center">}}

run this script:

{{< highlightfile file="Examples/specular/AlternatingLayers1.py">}}


### Explanation

The function ***get_simulation*** constructs a
{{% api-class "SpecularSimulation" %}}.
The constructor
{{% api-class "AlphaScan" %}} defines a scan
as function of inclination angles.
The arguments are wavelength, number of points, initial angle, final angle.

The ***Main program*** has been explained in the
[Syntax]({{% ref-py "start/syntax.md" %}}) page.
For alternative ways of running simulations and plotting or exporting results,
see section [Plot and export]({{% ref-py "result/_index.md" %}}).

Since we will use the same sample in several other examples,
we provide the shorthand `std_samples.alternating_layers()`
so that the above script can be shortened as

{{< highlightfile file="Examples/specular/AlternatingLayers2.py">}}

### Further reading

* [specular signal from a rough sample]({{% ref-py "sample/roughness/specular/index.md" %}})
* [beam footprint correction]({{% ref-py "instr/beam/footprint/index.md" %}})
* [beam divergence in specular simulations]({{% ref-py "instr/beam/full-divergence/index.md" %}})
* [fitting reflectometry data]({{% ref-py "fitting/extended/fit-specular-data/index.md" %}})
